@@ -2,16 +2,8 @@
 
 import logging
 
-from django.conf import settings
-from django.db import router, transaction
-from django.db.models import DateField, DateTimeField, F, IntegerField, Manager, Model
-from django.db.models.expressions import CombinedExpression
-from django.utils.module_loading import import_string
-
 from dj_cqrs.constants import (
     ALL_BASIC_FIELDS,
-    DEFAULT_CQRS_MAX_RETRIES,
-    DEFAULT_CQRS_RETRY_DELAY,
     FIELDS_TRACKER_FIELD_NAME,
     TRACKED_FIELDS_ATTR_NAME,
 )
@@ -19,6 +11,12 @@ from dj_cqrs.managers import MasterManager, ReplicaManager
 from dj_cqrs.metas import MasterMeta, ReplicaMeta
 from dj_cqrs.signals import MasterSignals, post_bulk_create, post_update
 
+from django.conf import settings
+from django.db import router, transaction
+from django.db.models import DateField, DateTimeField, F, IntegerField, Manager, Model
+from django.db.models.expressions import CombinedExpression
+from django.utils.module_loading import import_string
+
 
 logger = logging.getLogger('django-cqrs')
 
@@ -128,9 +126,7 @@ class RawMasterMixin(Model):
 
     @property
     def _update_cqrs_fields_default(self):
-        return bool(
-            getattr(settings, 'CQRS', {}).get('master', {}).get('CQRS_AUTO_UPDATE_FIELDS', False),
-        )
+        return settings.CQRS['master']['CQRS_AUTO_UPDATE_FIELDS']
 
     def to_cqrs_dict(self, using=None, sync=False):
         """CQRS serialization for transport payload.
@@ -270,7 +266,7 @@ class RawMasterMixin(Model):
 
             instance = self.relate_cqrs_serialization(qs).first()
             if not instance:
-                raise RuntimeError("Couldn't serialize CQRS class ({}).".format(self.CQRS_ID))
+                raise RuntimeError("Couldn't serialize CQRS class ({0}).".format(self.CQRS_ID))
 
         data = self._cqrs_serializer_cls(instance).data
         data['cqrs_revision'] = instance.cqrs_revision
@@ -312,7 +308,9 @@ class RawMasterMixin(Model):
             self.__class__._cqrs_serializer_class = serializer
             return serializer
         except ImportError:
-            raise ImportError("Model {}: CQRS_SERIALIZER can't be imported.".format(self.__class__))
+            raise ImportError(
+                "Model {0}: CQRS_SERIALIZER can't be imported.".format(self.__class__),
+            )
 
 
 class MasterMixin(RawMasterMixin, metaclass=MasterMeta):
@@ -423,20 +421,11 @@ class ReplicaMixin(Model, metaclass=ReplicaMeta):
         :return: True if message should be retried, False otherwise.
         :rtype: bool
         """
-        replica_settings = settings.CQRS.get('replica', {})
-        if 'CQRS_MAX_RETRIES' in replica_settings and replica_settings['CQRS_MAX_RETRIES'] is None:
+        max_retries = settings.CQRS['replica']['CQRS_MAX_RETRIES']
+        if max_retries is None:
             # Infinite
             return True
 
-        min_value = 0
-        max_retries = replica_settings.get('CQRS_MAX_RETRIES', DEFAULT_CQRS_MAX_RETRIES)
-        if not isinstance(max_retries, int) or max_retries < min_value:
-            logger.warning(
-                "Replica setting CQRS_MAX_RETRIES=%s is invalid, using default %s",
-                max_retries, DEFAULT_CQRS_MAX_RETRIES,
-            )
-            max_retries = DEFAULT_CQRS_MAX_RETRIES
-
         return current_retry < max_retries
 
     @staticmethod
@@ -448,18 +437,4 @@ class ReplicaMixin(Model, metaclass=ReplicaMeta):
         :return: Delay in seconds.
         :rtype: int
         """
-        retry_delay = (
-            settings.CQRS
-            .get('replica', {})
-            .get('CQRS_RETRY_DELAY', DEFAULT_CQRS_RETRY_DELAY)
-        )
-
-        min_value = 1
-        if not isinstance(retry_delay, int) or retry_delay < min_value:
-            logger.warning(
-                "Replica setting CQRS_RETRY_DELAY=%s is invalid, using default %s",
-                retry_delay, DEFAULT_CQRS_RETRY_DELAY,
-            )
-            retry_delay = DEFAULT_CQRS_RETRY_DELAY
-
-        return retry_delay
+        return settings.CQRS['replica']['CQRS_RETRY_DELAY']
