@@ -1,13 +1,14 @@
 #  Copyright © 2021 Ingram Micro Inc. All rights reserved.
 
+from dj_cqrs.constants import SignalType
+from dj_cqrs.controller import producer
+from dj_cqrs.dataclasses import TransportPayload
+from dj_cqrs.utils import get_message_expiration_dt
+
 from django.db import models, transaction
 from django.dispatch import Signal
 from django.utils.timezone import now
 
-from dj_cqrs.controller import producer
-from dj_cqrs.constants import SignalType
-from dj_cqrs.dataclasses import TransportPayload
-from dj_cqrs.utils import get_expires_datetime
 
 post_bulk_create = Signal(providing_args=['instances', 'using'])
 """
@@ -73,7 +74,7 @@ class MasterSignals:
                 instance.pk,
                 queue,
                 previous_data,
-                expires=get_expires_datetime(),
+                expires=get_message_expiration_dt(),
             )
             producer.produce(payload)
 
@@ -113,7 +114,7 @@ class MasterSignals:
             sender.CQRS_ID,
             instance_data,
             instance.pk,
-            expires=get_expires_datetime(),
+            expires=get_message_expiration_dt(),
         )
         # Delete is always in transaction!
         transaction.on_commit(lambda: producer.produce(payload))
